function experiment_model_simulator

% (c) Ali Tariq, 2018.

clc
close all
clear all

n = 10;   % The number of generations the simulation is run for.

T = 2.5;  % The length of time a generation is left to grow for. We keep it
          % the same for all generations.

tspan = linspace(0,T);  % Time interval over which a solution is plotted.
                        % This creates 100 evenly spaced points between 0
                        % and T.

A_mat = zeros(length(tspan),n); % This is a zero matrix which will accept
                                % the output values for each generation of
                                % aphids over the time interval. Each
                                % column will store the data for each
                                % generation.

% We will set up a loop to solve the equation for the n generations of
% aphids we want to run the simulation for. However the first generation
% of aphids will be unaffected by the transgenic plants, meaning their
% birth and death rates will vary from subseqent generations. Therefore, we
% will run the simulation for the first generation spearately and create a
% loop for generations 2 to n.

A0 = 25;     % The initial number of aphids in the first generation.
b0 = 0.25;    % The birth rate for the first generation.
d0 = 0.1;    % The death rate for the fiest generation.

[~,Sol] = ode45(@(t,A)growthode(t,A,b0,d0), tspan, A0);  % Call solver.

A_mat(:,1) = Sol; % Replace the first column of A_mat with the data output
                  % from solving the equation for the first generation.

% Now we run a loop to add to A_mat the equivalent data for the remaining
% generations (2 to n). We assume that for generation 2 onwards the
% birth and death rate remain the same. Should you want them to change for
% each generation you must define this directly in the loop.

b = 0.25;   % Birth rate of generation 2 to n.
d = 0.1;    % Death rate of generation 2 to n.
           
A_ini = ( (b0*A0) / (b0-d0) )*((exp((b0-d0)*T)) - 1); % Initial value for 
                                                      % subsequent
                                                      % generations.
    

for i = 2:n  % the loop runs from generation 2 to n. i is the iterator.
    
    [~,Sol] = ode45(@(t,A)growthode(t,A,b,d), tspan, A_ini); % Call solver.
    
    A_mat(:,i) = Sol; % Append the ith solution to the ith column of A_mat.
    
    A_ini = ( (b*A_ini) / (b-d) )*((exp((b-d)*T)) - 1); % Redefine the
                                                        % initial
                                                        % condition.
          
end

% At this point we should now have a 100xn matrix, A_mat, whose ith column
% contains the population growth data for the ith generation over the
% growth period of time length, T. We now plot the data on the (t,A) axis
% to allow better understanding of the generational growth or decay. This
% is also done by a loop but this time we don't need to give special
% consideration to generation 1.

    
hold on
grid on
grid minor  % Display gridlines on plot.

    
for i = 1:n
        
    plot(tspan, A_mat(:,i),'linewidth',2); % Plot the ith generation
                                           % against time.
    
    Legendinfo{i} = ['A' num2str(i)];  % Add to the legend generation A'i'.
        
    tspan = tspan + T; % Plot the (i+1)th generation T time units ahead of
                       % the ith generation.
        
end


legend(Legendinfo, 'location', 'best'); % Display and position the legend.

xlabel('time');
ylabel('Number of aphids'); % Label the axis appropriately.

end
    



function dAdt = growthode(t,A,b,d)

% This function defines the ODE that governs the growth of a single
% generation of aphids on a leaf disc. The equation is essentially the same
% for all generations of aphids, the important factors which may differ are
% the birth rate of aphids, b, and the death rate of aphids, d.

dAdt = b*A - d*A;

end
