function experiment_model_simulator_po

% (c) Ali Tariq, 2018.

clc
close all
clear all

% This function simulates the model in the situation where we get perfect
% oscillations. You can define the number of generations the simulation 
% runs for and the initial number of aphids for the first generation below:

n = 10;      % The number of generations the simulation is run for.

A0 = 25;     % The initial number of aphids in the first generation.

% Next you can choose the birth and death rate constants for each
% generation. Make sure that b is greater than d:

b = 0.7;     % The birth rate constant for every generation.
d = 0.5;     % The death rate constant for every generation.

% You cannot choose time each generation grows for. It automatically takes 
% the value required for perfect oscilations according to the formula
% below:

T = ( log( (b-d)/(b) + 1) )/(b-d) % The length of time a generation 
                                       % grows for. It's set to the time 
                                       % for perfect oscillations.

tspan = linspace(0,T);  % Time interval over which a solution is plotted.
                        % This creates 100 evenly spaced points between 0
                        % and T.

A_mat = zeros(length(tspan),n); % This is a zero matrix which will accept
                                % the output values for each generation of
                                % aphids over the time interval. Each
                                % column will store the data for each
                                % generation.

% Below we set up a loop to simulate the model and to store the solutions 
% to be plotted in a later loop:

for i = 1:n
    
    [~,Sol] = ode45(@(t,A)growthode(t,A,b,d), tspan, A0);  % Call solver.
    
    A_mat(:,i) = Sol; % append the solution to the ith column of A_mat.
    
    A0 = ( (b*A0) / (b-d) )*((exp((b-d)*T)) - 1); % Define the initial
                                                  % condition for the next
                                                  % generation.
    
end


% Next we make a loop to plot the solutions against time:
    
hold on
grid on
grid minor  % Display gridlines on plot.
    
for i = 1:n
        
    plot(tspan, A_mat(:,i),'linewidth',2); % Plot the ith generation
                                           % against time.
    
    Legendinfo{i} = ['A' num2str(i)];  % Add to the legend, generation A'i'
        
    tspan = tspan + T; % Plot the (i+1)th generation T time units ahead of
                       % the ith generation.
        
end


legend(Legendinfo, 'location', 'best'); % Display and position the legend.

xlabel('time');
ylabel('Number of aphids'); % Label the axis appropriately.
    
end



function dAdt = growthode(t,A,b,d)

% This function defines the ODE that governs the growth of a single
% generation of aphids on a leaf disc. The equation is essentially the same
% for all generations of aphids, the important factors which may differ are
% the birth rate of aphids, b, and the death rate of aphids, d.

dAdt = b*A - d*A;

end