function field_model

% (c) Ali Tariq, 2018.

clc
close all

% This function plots the solution of the model proposed to simulate what
% may happen in a field, it factors in the aphids, any predators, and the 
% plants as well.

% Below you can choose values for the different rate parameters in the
% equations.

m = 1;    % Migration of aphids into the field.

ba = 1;   % Birth rate of aphids.
bp = 1;   % Birth rate of predators.

da1 = 1;  % Natural death rate of aphids.
da2 = 1;  % Death rate of aphids due to predation.
dp = 1;   % Death rate of predators due to competition.

% Next you can assign values to the scaling multiplier for plant death,
% 'ea'. This exists to scale down the death of crop plants i.e. it
% is unrealistic to assume that a single aphid will consume an entire plant
% to birth one more aphid. So, to dampen this effect, it is sensible
% to choose a value for 'ea' to lie between 0 and 1. A smaller value means
% greater damping.

ea = 0.3; % Multiplier for plant death by aphids.

% Next you must choose the length of time you want to run the simulation
% for. Simply change the value of x in [0 x] below, to run the
% simulation for x units of time.

tspan = [0 10]; % The time interval the simulation is run for.

% Finally, you need to define some initial values for each population in
% the model. Namely, the initial number of aphids, predators and plants. 
% To do this change the values in the array below, the order is 
% [aphids; predators; plants]. Make sure your units are consistent with
% those used above.

y0 = [20;10;10]; % The initial value array.


% Now press run and MATLAB will do the rest.




[t,y] = ode45(@(t,y)ODEsys(t,y,m,ba,bp,da1,da2,dp,ea), tspan, y0); % Calls solver.

subplot(3,4,[1,2]); % Plots aphids.
plot(t,y(:,1),'linewidth',2);
xlabel('time');
ylabel('Number of aphids');

subplot(3,4,[3,4]) % Plots predators.
plot(t,y(:,2),'linewidth',2);
xlabel('time');
ylabel('Number of predators');

subplot(3,4,[6,7]) % Plots plants.
plot(t,y(:,3),'linewidth',2);
xlabel('time');
ylabel('Number of plants');

subplot(3,4,[9,12]); % Plots all 3 for comparison.
plot(t,y(:,1),'linewidth',2);
hold on
plot(t,y(:,2),'linewidth',2);
hold on
plot(t,y(:,3),'linewidth',2);
xlabel('time');
legend('Aphids','Predators','Plants','location','best');

end


% The function below simply defines the system of ODEs that simulate the
% interaction of aphids, predators and crop plants in the field. 
% For more details on the motivation behind the system please see the
% modelling guide.

function dydt = ODEsys(t,y,m,ba,bp,da1,da2,dp,ea)

dydt = zeros(3,1);

dydt(1) = m + ba*y(1)*y(3) - da1*y(1) - da2*y(1)*y(2);
dydt(2) = bp*y(1)*y(2) - dp*y(2)*y(2);
dydt(3) = - ea*ba*y(1)*y(3);

end